/* This file is part of the KDE libraries
    Copyright (C) 2005, 2006 KJSEmbed Authors
    See included AUTHORS file.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef BRUSH_H
#define BRUSH_H

#include "variant_binding.h"
#include "object_binding.h"
#include "static_binding.h"

class QBrush;

namespace KJSEmbed
{
    /** @internal Implements the binding for QBrush. */
    class BrushBinding : public VariantBinding
    {
        public:
            BrushBinding( KJS::ExecState *exec, const QBrush &value );
            virtual const KJS::ClassInfo* classInfo() const { return &info; }
            static const KJS::ClassInfo info;
    };


    KJS_BINDING( Brush )
}
#endif
//kate: indent-spaces on; indent-width 4; replace-tabs on; indent-mode cstyle;
